/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.converter;

import static org.assertj.core.api.Assertions.*;

import java.text.ParseException;
import java.time.ZonedDateTime;

import org.junit.jupiter.api.Test;

class ZonedDateTimeWriteConverterTest {

	private final String DATE_STR = "2021-01-19T08:34:13Z";

	private ZonedDateTimeWriteConverter converter = new ZonedDateTimeWriteConverter();

	@Test
	void shouldConvertFromDateToZonedDateTime() throws ParseException {
		ZonedDateTime date = ZonedDateTime.parse(DATE_STR);

		var convertedDate = converter.convert(date);

		assertThat(convertedDate).isEqualTo(DATE_STR);
	}

	@Test
	void shouldConvertToUTC() throws ParseException {
		var date = ZonedDateTime.parse("2021-01-18T07:00:00+01:00");

		var convertedDate = converter.convert(date);

		assertThat(convertedDate).isEqualTo("2021-01-18T06:00:00Z");
	}
}