package de.ozgcloud.vorgang.common.migration;

import static de.ozgcloud.vorgang.common.migration.M003_UpdateClientNameInVorgangAttachedItem.*;
import static de.ozgcloud.vorgang.common.migration.RenameTestFactory.*;
import static org.assertj.core.api.Assertions.*;

import org.bson.Document;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Query;

import de.ozgcloud.common.test.DataITCase;

@DataITCase
class M003_UpdateClientNameInVorgangAttachedItemITCase {

	private static final Document OLD_CLIENT_NAME_VORGANG_ATTACHED_ITEM = RenameTestFactory.createVorgangAttachedItem(OLD_CLIENT_NAME);

	private final M003_UpdateClientNameInVorgangAttachedItem migration = new M003_UpdateClientNameInVorgangAttachedItem();

	@Autowired
	private MigrationDbTestUtils dbTestUtils;
	@Autowired
	private MongoTemplate template;

	@BeforeEach
	public void init() {
		dbTestUtils.dropVorgangAttachedItemCollection();
	}

	@DisplayName("Do migration")
	@Nested
	class TestDoMigration {

		@BeforeEach
		void init() {
			dbTestUtils.saveVorgangAttachedItem(OLD_CLIENT_NAME_VORGANG_ATTACHED_ITEM);
		}

		@Test
		void shouldUpdateClientName() {
			migration.doMigration(template);

			assertThat(getVorgangAttachedItem()).containsEntry(RenameUtil.CLIENT_KEY, NEW_CLIENT_NAME);
		}

		@Test
		void shouldKeeptOtherAttributes() {
			migration.doMigration(template);

			assertThat(getVorgangAttachedItem())
					.containsEntry(ITEM_NAME_KEY, ITEM_NAME_VALUE)
					.containsKey(ITEM_KEY);
		}

		@Test
		void shouldKeepItemAttributes() {
			migration.doMigration(template);

			var item = (Document) getVorgangAttachedItem().get(ITEM_KEY);
			assertThat(item).containsExactly(entry(ITEM_ATTRIBUTE_KEY, ITEM_ATTRIBUTE_VALUE));
		}

		private Document getVorgangAttachedItem() {
			return dbTestUtils.findVorgangAttachedItem(new Query()).get(0);
		}
	}
}